diff --git a/http-conduit-downloader.cabal b/http-conduit-downloader.cabal
--- a/http-conduit-downloader.cabal
+++ b/http-conduit-downloader.cabal
@@ -1,6 +1,6 @@
 cabal-version:  >= 1.6
 name:           http-conduit-downloader
-version:        1.0.2
+version:        1.0.3
 copyright:      Vladimir Shabanov 2013
 author:         Vladimir Shabanov <vshabanoff@gmail.com>
 maintainer:     Vladimir Shabanov <vshabanoff@gmail.com>

diff --git a/Network/HTTP/Conduit/Downloader.hs b/Network/HTTP/Conduit/Downloader.hs
--- a/Network/HTTP/Conduit/Downloader.hs
+++ b/Network/HTTP/Conduit/Downloader.hs
@@ -227,9 +227,13 @@
                   `E.catch`
                     (return . Just . someException)
                 case r of
-                    Just (DRError e) | "EOF reached" `isSuffixOf` e && firstTime ->
+                    Just (DRError e)
+                        | ("EOF reached" `isSuffixOf` e ||
+                           e == "Invalid HTTP status line:\n"
+                          ) && firstTime ->
                         dl False
                         -- "EOF reached" can happen on servers that fails to
                         -- implement HTTP/1.1 persistent connections.
                         -- Try again
                         -- https://github.com/snoyberg/http-conduit/issues/89
@@ -227,9 +227,13 @@
                         dl False
-                        -- "EOF reached" can happen on servers that fails to
+                        -- "EOF reached" or empty HTTP status line
+                        -- can happen on servers that fails to
                         -- implement HTTP/1.1 persistent connections.
                         -- Try again